/*
 * This is the license for the control panel pattern example files.
 * 
 * Copyright (C) 2008 Johan Thelin <johan.thelin@bitsim.com>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the
 * following conditions are met:
 * 
 *   - Redistributions of source code must retain the above
 *     copyright notice, this list of conditions and the
 *     following disclaimer.
 *   - Redistributions in binary form must reproduce the
 *     above copyright notice, this list of conditions and
 *     the following disclaimer in the documentation and/or
 *     other materials provided with the distribution.
 *   - The names of its contributors may be used to endorse
 *     or promote products derived from this software without
 *     specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "recordingspanel.h"

#include "recordings.h"

#include "panelstack.h"

#include "recordingdetailspanel.h"

RecordingsPanel *RecordingsPanel::m_instance = 0;
RecordingsPanel *RecordingsPanel::instance()
{
	if( !m_instance )
	{
		m_instance = new RecordingsPanel();
		m_instance->addPanelToStack();
	}

	return m_instance;
}

RecordingsPanel::RecordingsPanel() : AbstractPanel()
{
	ui.setupUi( this );

	connect( ui.addButton, SIGNAL(clicked()), SLOT(addClicked()) );
	connect( ui.editButton, SIGNAL(clicked()), SLOT(editClicked()) );
	connect( ui.removeButton, SIGNAL(clicked()), SLOT(removeClicked()) );
	connect( ui.backButton, SIGNAL(clicked()), PanelStack::instance(), SLOT(back()) );
}

void RecordingsPanel::showPanel()
{
	PanelStack::instance()->showPanel( panelIndex() );
}

QString RecordingsPanel::titleText() const { return tr("Scheduled Recordings"); }

void RecordingsPanel::enterPanel()
{
	ui.recordingsList->clear();
	foreach( QString s, recordings )
		ui.recordingsList->addItem( s );
}

void RecordingsPanel::addClicked()
{
	RecordingDetailsPanel::instance()->showPanel( -1 );
}

void RecordingsPanel::editClicked()
{
	if( ui.recordingsList->currentRow() == -1 )
	    return;
	
	RecordingDetailsPanel::instance()->showPanel( ui.recordingsList->currentRow() );
}

void RecordingsPanel::removeClicked()
{
	if( ui.recordingsList->currentRow() == -1 )
	    return;
	
	recordings.removeAt( ui.recordingsList->currentRow() );
	delete ui.recordingsList->takeItem( ui.recordingsList->currentRow() );
}
